@@ -10,7 +10,7 @@ use std::io::{Cursor, Read, Seek, SeekFrom, Write};
 use byteorder::WriteBytesExt;
 
 #[allow(clippy::shadow_unrelated)]
-pub(crate) fn write_id3v1(writer: &mut File, tag: &Id3v1TagRef) -> Result<()> {
+pub(crate) fn write_id3v1(writer: &mut File, tag: &Id3v1TagRef<'_>) -> Result<()> {
 	let probe = Probe::new(writer).guess_file_type()?;
 
 	match probe.file_type() {
@@ -43,8 +43,8 @@ pub(crate) fn write_id3v1(writer: &mut File, tag: &Id3v1TagRef) -> Result<()> {
 	Ok(())
 }
 
-pub(super) fn encode(tag: &Id3v1TagRef) -> Result<Vec<u8>> {
-	fn resize_string(value: Option<&str>, size: usize) -> Result<Vec<u8>> {
+pub(super) fn encode(tag: &Id3v1TagRef<'_>) -> std::io::Result<Vec<u8>> {
+	fn resize_string(value: Option<&str>, size: usize) -> std::io::Result<Vec<u8>> {
 		let mut cursor = Cursor::new(vec![0; size]);
 		cursor.seek(SeekFrom::Start(0))?;
 
