@@ -1,4 +1,5 @@
-use crate::error::{LoftyError, Result};
+use crate::error::{FileDecodingError, Result};
+use crate::types::file::FileType;
 use crate::types::properties::FileProperties;
 
 use std::io::Read;
@@ -14,11 +15,11 @@ pub(super) fn read_properties(
 	let channels = comm.read_u16::<BigEndian>()? as u8;
 
 	if channels == 0 {
-		return Err(LoftyError::Aiff("File contains 0 channels"));
+		return Err(FileDecodingError::new(FileType::AIFF, "File contains 0 channels").into());
 	}
 
 	let sample_frames = comm.read_u32::<BigEndian>()?;
-	let _sample_size = comm.read_u16::<BigEndian>()?;
+	let sample_size = comm.read_u16::<BigEndian>()?;
 
 	let mut sample_rate_bytes = [0; 10];
 	comm.read_exact(&mut sample_rate_bytes)?;
@@ -66,6 +67,7 @@ pub(super) fn read_properties(
 		overall_bitrate,
 		audio_bitrate,
 		sample_rate: Some(sample_rate),
+		bit_depth: Some(sample_size as u8),
 		channels: Some(channels),
 	})
 }
