@@ -11,19 +11,20 @@ use std::fs::File;
 pub(crate) fn write_to(data: &mut File, tag: &Tag) -> Result<()> {
 	match tag.tag_type() {
 		#[cfg(feature = "aiff_text_chunks")]
-		TagType::AiffText => super::tag::AiffTextChunksRef::new(
-			tag.get_string(&ItemKey::TrackTitle),
-			tag.get_string(&ItemKey::TrackArtist),
-			tag.get_string(&ItemKey::CopyrightMessage),
-			Some(tag.get_texts(&ItemKey::Comment)),
-			None,
-		)
+		TagType::AiffText => super::tag::AiffTextChunksRef {
+			name: tag.get_string(&ItemKey::TrackTitle),
+			author: tag.get_string(&ItemKey::TrackArtist),
+			copyright: tag.get_string(&ItemKey::CopyrightMessage),
+			annotations: Some(tag.get_texts(&ItemKey::Comment)),
+			comments: None,
+		}
 		.write_to(data),
 		#[cfg(feature = "id3v2")]
-		TagType::Id3v2 => {
-			v2::tag::Id3v2TagRef::new(v2::Id3v2TagFlags::default(), v2::tag::tag_frames(tag))
-				.write_to(data)
-		},
+		TagType::Id3v2 => v2::tag::Id3v2TagRef {
+			flags: v2::Id3v2TagFlags::default(),
+			frames: v2::tag::tag_frames(tag),
+		}
+		.write_to(data),
 		_ => Err(LoftyError::new(ErrorKind::UnsupportedTag)),
 	}
 }
