@@ -1,11 +1,11 @@
 use crate::error::Result;
+use crate::macros::try_vec;
 
 use std::io::{Read, Seek, SeekFrom};
 
 use byteorder::{BigEndian, ReadBytesExt};
 
 pub(super) struct Block {
-	#[allow(unused)]
 	pub(super) byte: u8,
 	pub(super) ty: u8,
 	pub(super) last: bool,
@@ -27,7 +27,7 @@ impl Block {
 
 		let size = data.read_uint::<BigEndian>(3)? as u32;
 
-		let mut content = vec![0; size as usize];
+		let mut content = try_vec![0; size as usize];
 		data.read_exact(&mut content)?;
 
 		let end = data.seek(SeekFrom::Current(0))?;
