@@ -1,4 +1,4 @@
-//! OPUS/FLAC/Vorbis specific items
+//! Items for OGG container formats
 //!
 //! ## File notes
 //!
@@ -7,26 +7,35 @@ pub(crate) mod constants;
 pub(crate) mod flac;
 pub(crate) mod opus;
 pub(crate) mod read;
-#[cfg(feature = "vorbis_comments")]
-pub(crate) mod tag;
+pub(crate) mod speex;
 pub(crate) mod vorbis;
-#[cfg(feature = "vorbis_comments")]
-pub(crate) mod write;
 
 use crate::error::{FileDecodingError, Result};
-pub use crate::ogg::flac::FlacFile;
-pub use crate::ogg::opus::properties::OpusProperties;
-pub use crate::ogg::opus::OpusFile;
-#[cfg(feature = "vorbis_comments")]
-pub use crate::ogg::tag::VorbisComments;
-pub use crate::ogg::vorbis::properties::VorbisProperties;
-pub use crate::ogg::vorbis::VorbisFile;
 use crate::types::file::FileType;
 
 use std::io::{Read, Seek};
 
 use ogg_pager::Page;
 
+// Exports
+
+cfg_if::cfg_if! {
+	if #[cfg(feature = "vorbis_comments")] {
+		pub(crate) mod write;
+
+		pub(crate) mod tag;
+		pub use tag::VorbisComments;
+	}
+}
+
+pub use flac::FlacFile;
+pub use opus::properties::OpusProperties;
+pub use opus::OpusFile;
+pub use speex::properties::SpeexProperties;
+pub use speex::SpeexFile;
+pub use vorbis::properties::VorbisProperties;
+pub use vorbis::VorbisFile;
+
 pub(self) fn verify_signature(page: &Page, sig: &[u8]) -> Result<()> {
 	let sig_len = sig.len();
 
