@@ -1,6 +1,7 @@
 use super::properties::FileProperties;
 use super::tag::{Tag, TagType};
-use crate::error::{ErrorKind, LoftyError, Result};
+use crate::error::Result;
+use crate::tag_traits::TagExt;
 
 use std::convert::TryInto;
 use std::ffi::OsStr;
@@ -9,7 +10,7 @@ use std::io::{Read, Seek};
 use std::path::Path;
 
 /// Provides various methods for interaction with a file
-pub trait AudioFile {
+pub trait AudioFile: Into<TaggedFile> {
 	/// The struct the file uses for audio properties
 	///
 	/// Not all formats can use [`FileProperties`] since they may contain additional information
@@ -19,7 +20,7 @@ pub trait AudioFile {
 	///
 	/// # Errors
 	///
-	/// Errors depend on the file and tags being read. See [`LoftyError`]
+	/// Errors depend on the file and tags being read. See [`LoftyError`](crate::LoftyError)
 	fn read_from<R>(reader: &mut R, read_properties: bool) -> Result<Self>
 	where
 		R: Read + Seek,
@@ -29,7 +30,7 @@ pub trait AudioFile {
 	/// Checks if the file contains any tags
 	fn contains_tag(&self) -> bool;
 	/// Checks if the file contains the given [`TagType`]
-	fn contains_tag_type(&self, tag_type: &TagType) -> bool;
+	fn contains_tag_type(&self, tag_type: TagType) -> bool;
 }
 
 /// A generic representation of a file
@@ -45,6 +46,43 @@ pub struct TaggedFile {
 }
 
 impl TaggedFile {
+	/// Returns the file's [`FileType`]
+	pub fn file_type(&self) -> FileType {
+		self.ty
+	}
+
+	/// Returns the file's [`FileProperties`]
+	pub fn properties(&self) -> &FileProperties {
+		&self.properties
+	}
+
+	/// Returns all tags
+	pub fn tags(&self) -> &[Tag] {
+		self.tags.as_slice()
+	}
+
+	/// Returns the file type's primary [`TagType`]
+	///
+	/// See [`FileType::primary_tag_type`]
+	pub fn primary_tag_type(&self) -> TagType {
+		self.ty.primary_tag_type()
+	}
+
+	/// Determines whether the file supports the given [`TagType`]
+	pub fn supports_tag_type(&self, tag_type: TagType) -> bool {
+		self.ty.supports_tag_type(tag_type)
+	}
+
+	/// Get a reference to a specific [`TagType`]
+	pub fn tag(&self, tag_type: &TagType) -> Option<&Tag> {
+		self.tags.iter().find(|i| i.tag_type() == *tag_type)
+	}
+
+	/// Get a mutable reference to a specific [`TagType`]
+	pub fn tag_mut(&mut self, tag_type: &TagType) -> Option<&mut Tag> {
+		self.tags.iter_mut().find(|i| i.tag_type() == *tag_type)
+	}
+
 	/// Returns the primary tag
 	///
 	/// See [`FileType::primary_tag_type`]
@@ -59,23 +97,6 @@ impl TaggedFile {
 		self.tag_mut(&self.primary_tag_type())
 	}
 
-	/// Returns the file type's primary [`TagType`]
-	///
-	/// See [`FileType::primary_tag_type`]
-	pub fn primary_tag_type(&self) -> TagType {
-		self.ty.primary_tag_type()
-	}
-
-	/// Determines whether the file supports the given [`TagType`]
-	pub fn supports_tag_type(&self, tag_type: TagType) -> bool {
-		self.ty.supports_tag_type(&tag_type)
-	}
-
-	/// Returns all tags
-	pub fn tags(&self) -> &[Tag] {
-		self.tags.as_slice()
-	}
-
 	/// Gets the first tag, if there are any
 	pub fn first_tag(&self) -> Option<&Tag> {
 		self.tags.first()
@@ -86,16 +107,6 @@ impl TaggedFile {
 		self.tags.first_mut()
 	}
 
-	/// Get a reference to a specific [`TagType`]
-	pub fn tag(&self, tag_type: &TagType) -> Option<&Tag> {
-		self.tags.iter().find(|i| i.tag_type() == tag_type)
-	}
-
-	/// Get a mutable reference to a specific [`TagType`]
-	pub fn tag_mut(&mut self, tag_type: &TagType) -> Option<&mut Tag> {
-		self.tags.iter_mut().find(|i| i.tag_type() == tag_type)
-	}
-
 	/// Inserts a [`Tag`]
 	///
 	/// NOTE: This will do nothing if the [`FileType`] does not support
@@ -103,7 +114,7 @@ impl TaggedFile {
 	///
 	/// If a tag is replaced, it will be returned
 	pub fn insert_tag(&mut self, tag: Tag) -> Option<Tag> {
-		let tag_type = *tag.tag_type();
+		let tag_type = tag.tag_type();
 
 		if self.supports_tag_type(tag_type) {
 			let ret = self.remove_tag(tag_type);
@@ -121,7 +132,7 @@ impl TaggedFile {
 	pub fn remove_tag(&mut self, tag_type: TagType) -> Option<Tag> {
 		self.tags
 			.iter()
-			.position(|t| t.tag_type() == &tag_type)
+			.position(|t| t.tag_type() == tag_type)
 			.map(|pos| self.tags.remove(pos))
 	}
 
@@ -166,18 +177,6 @@ impl TaggedFile {
 	}
 }
 
-impl TaggedFile {
-	/// Returns the file's [`FileType`]
-	pub fn file_type(&self) -> &FileType {
-		&self.ty
-	}
-
-	/// Returns a reference to the file's [`FileProperties`]
-	pub fn properties(&self) -> &FileProperties {
-		&self.properties
-	}
-}
-
 #[derive(PartialEq, Copy, Clone, Debug)]
 #[allow(missing_docs)]
 #[non_exhaustive]
@@ -190,6 +189,7 @@ pub enum FileType {
 	MP4,
 	Opus,
 	Vorbis,
+	Speex,
 	WAV,
 }
 
@@ -217,32 +217,36 @@ impl FileType {
 			#[cfg(all(not(feature = "ape"), feature = "id3v1"))]
 			FileType::MP3 => TagType::Id3v1,
 			FileType::APE => TagType::Ape,
-			FileType::FLAC | FileType::Opus | FileType::Vorbis => TagType::VorbisComments,
+			FileType::FLAC | FileType::Opus | FileType::Vorbis | FileType::Speex => {
+				TagType::VorbisComments
+			},
 			FileType::MP4 => TagType::Mp4Ilst,
 		}
 	}
 
 	/// Returns if the target `FileType` supports a [`TagType`]
-	pub fn supports_tag_type(&self, tag_type: &TagType) -> bool {
+	pub fn supports_tag_type(&self, tag_type: TagType) -> bool {
 		match self {
 			#[cfg(feature = "id3v2")]
 			FileType::AIFF | FileType::APE | FileType::MP3 | FileType::WAV
-				if tag_type == &TagType::Id3v2 =>
+				if tag_type == TagType::Id3v2 =>
 			{
 				true
 			},
 			#[cfg(feature = "aiff_text_chunks")]
-			FileType::AIFF if tag_type == &TagType::AiffText => true,
+			FileType::AIFF if tag_type == TagType::AiffText => true,
 			#[cfg(feature = "id3v1")]
-			FileType::APE | FileType::MP3 if tag_type == &TagType::Id3v1 => true,
+			FileType::APE | FileType::MP3 if tag_type == TagType::Id3v1 => true,
 			#[cfg(feature = "ape")]
-			FileType::APE | FileType::MP3 if tag_type == &TagType::Ape => true,
+			FileType::APE | FileType::MP3 if tag_type == TagType::Ape => true,
 			#[cfg(feature = "vorbis_comments")]
-			FileType::Opus | FileType::FLAC | FileType::Vorbis => tag_type == &TagType::VorbisComments,
+			FileType::Opus | FileType::FLAC | FileType::Vorbis | FileType::Speex => {
+				tag_type == TagType::VorbisComments
+			},
 			#[cfg(feature = "mp4_ilst")]
-			FileType::MP4 => tag_type == &TagType::Mp4Ilst,
+			FileType::MP4 => tag_type == TagType::Mp4Ilst,
 			#[cfg(feature = "riff_info_list")]
-			FileType::WAV => tag_type == &TagType::RiffInfo,
+			FileType::WAV => tag_type == TagType::RiffInfo,
 			_ => false,
 		}
 	}
@@ -263,32 +267,18 @@ impl FileType {
 			"flac" => Some(Self::FLAC),
 			"ogg" => Some(Self::Vorbis),
 			"mp4" | "m4a" | "m4b" | "m4p" | "m4r" | "m4v" | "3gp" => Some(Self::MP4),
+			"spx" => Some(Self::Speex),
 			_ => None,
 		}
 	}
 
-	/// Attempts to extract a [`FileType`] from a path
-	///
-	/// # Errors
-	///
-	/// This will return [`ErrorKind::BadExtension`] if the extension didn't map to a `FileType`
-	pub fn from_path<P>(path: P) -> Result<Self>
+	/// Attempts to determine a [`FileType`] from a path
+	pub fn from_path<P>(path: P) -> Option<Self>
 	where
 		P: AsRef<Path>,
 	{
 		let ext = path.as_ref().extension();
-
-		ext.and_then(Self::from_ext).map_or_else(
-			|| {
-				let ext_err = match ext {
-					Some(ext) => ext.to_string_lossy().into_owned(),
-					None => String::new(),
-				};
-
-				Err(LoftyError::new(ErrorKind::BadExtension(ext_err)))
-			},
-			Ok,
-		)
+		ext.and_then(Self::from_ext)
 	}
 
 	/// Attempts to extract a [`FileType`] from a buffer
@@ -345,8 +335,8 @@ impl FileType {
 	fn quick_type_guess(buf: &[u8]) -> Option<Self> {
 		use crate::mp3::header::verify_frame_sync;
 
-		// Safe to unwrap, since we return early on an empty buffer
-		match buf.first().unwrap() {
+		// Safe to index, since we return early on an empty buffer
+		match buf[0] {
 			77 if buf.starts_with(b"MAC") => Some(Self::APE),
 			255 if buf.len() >= 2 && verify_frame_sync([buf[0], buf[1]]) => Some(Self::MP3),
 			70 if buf.len() >= 12 && &buf[..4] == b"FORM" => {
@@ -363,6 +353,8 @@ impl FileType {
 					return Some(Self::Vorbis);
 				} else if &buf[28..36] == b"OpusHead" {
 					return Some(Self::Opus);
+				} else if &buf[28..36] == b"Speex   " {
+					return Some(Self::Speex);
 				}
 
 				None
